/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 * Class con.docFlow.vaadin.fileExplorer.DirContentView.java created on 08.03.2012 by steffen.c-on
 *   *   *   *   *   *   *   *   *   *   *   *   *   *   *   *   *   *   *   *
 * (C) Copyright by c-on Services Steffen Ewert 2012; All rights reserved.
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 */

package com.example.vaadintest;

import com.vaadin.data.Property;
import com.vaadin.server.ExternalResource;
import com.vaadin.ui.Link;
import com.vaadin.ui.Table;

import java.text.DecimalFormat;
import java.util.List;

/** View component for displaying a directory content.
 *  This view displays the files contained by the directory in a table with some action buttons below of the
 *  table.
 * @author steffen.c-on
 * @version 08.03.2012
 */
class ChangeSetFileTable extends Table {

  /** serial ID */
  private static final long serialVersionUID = 8011165027135327358L;
  
  /** I18N key for the "Directory" label */
  public final static String I18N_DIR = "changeSet_colDir";
  /**
   * I18N key for the "Document name" label
   */
  public final static String I18N_BASE_NAME = "changeSet_colName";
  /** I18N key for the "Size" label */
  public final static String I18N_SIZE = "changeSet_colSize";
  /**
   * I18N key for the "File type" label
   */
  public final static String I18N_FILE_TYPE = "changeSet_colType";
  /**
   * I18N key for the "File Version" label
   */
  public final static String I18N_FILE_VERSION = "changeSet_colVersion";

  /** Column ID: read state */
  protected static final String COL_DIR = "dir"; 
  /** Column ID: file name */
  protected static final String COL_NAME = "name"; 
  /** Column ID: file size */
  protected static final String COL_SIZE = "size"; 
  /** Column ID: file type */
  protected static final String COL_TYPE = "type";
  /** Column ID: version */
  protected static final String COL_VERSION = "version";

  /** Construct a new DirContentView object.
   */
  public ChangeSetFileTable() {
    init();
  }

  /** Initialised this table.
   */
  private void init() {
    setSelectable(true);
    setMultiSelect(true);
//    setImmediate(true);
    
    addHeaderClickListener(new EventHandler());
  }    
  
  /** {@inheritDoc}
   */
  @Override
  public void attach() {
    super.attach();
  }

  /** Fills the file table.
   * @param fileContainer the files to fill
   */
  public void fillFileTable() {
    addContainerProperty(COL_DIR, Link.class, null);
    addContainerProperty(COL_NAME, Link.class, null);
    addContainerProperty(COL_VERSION, Link.class, null);
    addContainerProperty(COL_TYPE, String.class, null);
    addContainerProperty(COL_SIZE, Long.class, null);
    
    // set columns
    setColumnHeaders(new String[]{"DIR", "BASE_NAME", "FILE_VERSION", "FILE_TYPE", "SIZE"});

    // adjust some columns
    setColumnAlignment(COL_SIZE, Align.RIGHT);
    setColumnAlignment(COL_TYPE, Align.CENTER);
    setColumnAlignment(COL_VERSION, Align.CENTER);

    setColumnWidth(COL_SIZE, 64);
    setColumnWidth(COL_NAME, 180);
    setColumnWidth(COL_VERSION, 30);
    setColumnWidth(COL_TYPE, 30);

    // fill rows
    removeAllItems();
    
    ExternalResource res = new ExternalResource("https://www.yahoo.de");
    
    // the state icon label
    for (long i = 0; i < 10; i++) {
      
      addItem(new Object[]{new Link("1." + i, res), new Link("2." + i, res), new Link("3." + i, res), 
          "type 4." + i, i}, new Long(i).toString());
    }
    
    setSortContainerPropertyId(COL_NAME);
    setSortAscending(true);
  }

  /** {@inheritDoc}
   */
  @Override
  protected String formatPropertyValue(Object rowId, Object colId, Property<?> property) {
    if (property != null && property.getValue() != null) {
      if (COL_SIZE.equals(colId)) { // file size value --> convert to a number string
        return convertNumber((Long) property.getValue());
        
      }
    }
    
    return super.formatPropertyValue(rowId, colId, property);
  }
  
  /** Convert a number to a string.
   * @param no the number to convert
   * @return the number string
   */ 
  private String convertNumber(long no) {
    DecimalFormat format = new DecimalFormat();
    
    format.setGroupingUsed(true);
    
    return format.format(no);
  }
  
//  /** Converts the specified date into a string.
//   * @return date as the locale string
//   */
//  private String convertDate(Date date) {
//    DateFormat format = DateFormat.getDateTimeInstance();
//    
//    return format.format(date);
//  }

  /** Event handler class.
   */
  private class EventHandler implements Table.HeaderClickListener {

    /** serial number of this class */
    private static final long serialVersionUID = 1L;

    @Override
    public void headerClick(HeaderClickEvent event) {
      // store the new sort column
//      DocFlowUI dfApp = VaadinUtilSvc.getApplicationOf(ChangeSetFileTable.this);
//      User_ChangeSetFileTable_Properties.setSortOrderColID(dfApp.getLiUser(), getSortContainerPropertyId(), 
//          isSortAscending());

      System.out.println("Click!!!!!!");
      
    }
    
  }
}


// (C) Copyright by c-on Services Steffen Ewert 2012; All rights reserved.